nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Atlptd

Struct Atlptd 

#[repr(transparent)]
pub struct Atlptd(pub u32);
Memory base address where ATL PTD0 is stored

Tuple Fields

0: u32

Implementations

Source

impl Atlptd

pub const fn atl_cur(&self) -> u8

This indicates the current PTD that is used by the hardware when it is processing the ATL list.

pub const fn set_atl_cur(&mut self, val: u8)

This indicates the current PTD that is used by the hardware when it is processing the ATL list.

pub const fn atl_base(&self) -> u32

Base address to be used by the hardware to find the start of the ATL list.

pub const fn set_atl_base(&mut self, val: u32)

Base address to be used by the hardware to find the start of the ATL list.