nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Atlptds

Struct Atlptds 

#[repr(transparent)]
pub struct Atlptds(pub u32);
Skip map for each ATL PTD

Tuple Fields

0: u32

Implementations

Source

impl Atlptds

pub const fn atl_skip(&self) -> u32

When a bit in the PTD Skip Map is set to logic 1, the corresponding PTD will be skipped, independent of the V bit setting.

pub const fn set_atl_skip(&mut self, val: u32)

When a bit in the PTD Skip Map is set to logic 1, the corresponding PTD will be skipped, independent of the V bit setting.