nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

CaplengthChipid

Struct CaplengthChipid 

#[repr(transparent)]
pub struct CaplengthChipid(pub u32);
This register contains the offset value towards the start of the operational register space and the version number of the IP block

Tuple Fields

0: u32

Implementations

Source

impl CaplengthChipid

pub const fn caplength(&self) -> u8

Capability Length: This is used as an offset.

pub const fn set_caplength(&mut self, val: u8)

Capability Length: This is used as an offset.

pub const fn chipid(&self) -> u16

Chip identification: indicates major and minor revision of the IP: [31:24] = Major revision [23:16] = Minor revision Major revisions used: 0x01: USB2.

pub const fn set_chipid(&mut self, val: u16)

Chip identification: indicates major and minor revision of the IP: [31:24] = Major revision [23:16] = Minor revision Major revisions used: 0x01: USB2.