#[repr(transparent)]pub struct Hcsparams(pub u32);Expand description
Host Controller Structural Parameters
Tuple Fields
0: u32Implementations
Sourceimpl Hcsparams
impl Hcsparams
Sourcepub const fn n_ports(&self) -> u8
pub const fn n_ports(&self) -> u8
This register specifies the number of physical downstream ports implemented on this host controller.
Sourcepub const fn set_n_ports(&mut self, val: u8)
pub const fn set_n_ports(&mut self, val: u8)
This register specifies the number of physical downstream ports implemented on this host controller.
Sourcepub const fn ppc(&self) -> bool
pub const fn ppc(&self) -> bool
This field indicates whether the host controller implementation includes port power control.
Sourcepub const fn set_ppc(&mut self, val: bool)
pub const fn set_ppc(&mut self, val: bool)
This field indicates whether the host controller implementation includes port power control.
Sourcepub const fn p_indicator(&self) -> bool
pub const fn p_indicator(&self) -> bool
This bit indicates whether the ports support port indicator control.
Sourcepub const fn set_p_indicator(&mut self, val: bool)
pub const fn set_p_indicator(&mut self, val: bool)
This bit indicates whether the ports support port indicator control.