#[repr(transparent)]pub struct Intptd(pub u32);Expand description
Memory base address where INT PTD0 is stored
Tuple Fields
0: u32Implementations
Sourceimpl Intptd
impl Intptd
Sourcepub const fn int_first(&self) -> u8
pub const fn int_first(&self) -> u8
This indicates the first PTD that is used by the hardware when it is processing the INT list.
Sourcepub const fn set_int_first(&mut self, val: u8)
pub const fn set_int_first(&mut self, val: u8)
This indicates the first PTD that is used by the hardware when it is processing the INT list.
Sourcepub const fn int_base(&self) -> u32
pub const fn int_base(&self) -> u32
Base address to be used by the hardware to find the start of the INT list.
Sourcepub const fn set_int_base(&mut self, val: u32)
pub const fn set_int_base(&mut self, val: u32)
Base address to be used by the hardware to find the start of the INT list.