nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Isoptd

Struct Isoptd 

#[repr(transparent)]
pub struct Isoptd(pub u32);
Memory base address where ISO PTD0 is stored

Tuple Fields

0: u32

Implementations

Source

impl Isoptd

pub const fn iso_first(&self) -> u8

This indicates the first PTD that is used by the hardware when it is processing the ISO list.

pub const fn set_iso_first(&mut self, val: u8)

This indicates the first PTD that is used by the hardware when it is processing the ISO list.

pub const fn iso_base(&self) -> u32

Base address to be used by the hardware to find the start of the ISO list.

pub const fn set_iso_base(&mut self, val: u32)

Base address to be used by the hardware to find the start of the ISO list.