nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Lastptd

Struct Lastptd 

#[repr(transparent)]
pub struct Lastptd(pub u32);
Marks the last PTD in the list for ISO, INT and ATL

Tuple Fields

0: u32

Implementations

Source

impl Lastptd

pub const fn atl_last(&self) -> u8

If hardware has reached this PTD and the J bit is not set, it will go to PTD0 as the next PTD to be processed.

pub const fn set_atl_last(&mut self, val: u8)

If hardware has reached this PTD and the J bit is not set, it will go to PTD0 as the next PTD to be processed.

pub const fn iso_last(&self) -> u8

This indicates the last PTD in the ISO list.

pub const fn set_iso_last(&mut self, val: u8)

This indicates the last PTD in the ISO list.

pub const fn int_last(&self) -> u8

This indicates the last PTD in the INT list.

pub const fn set_int_last(&mut self, val: u8)

This indicates the last PTD in the INT list.