#[repr(transparent)]pub struct Usbcmd(pub u32);Expand description
USB Command register
Tuple Fields
0: u32Implementations
Sourceimpl Usbcmd
impl Usbcmd
Sourcepub const fn hcreset(&self) -> bool
pub const fn hcreset(&self) -> bool
Host Controller Reset: This control bit is used by the software to reset the host controller.
Sourcepub const fn set_hcreset(&mut self, val: bool)
pub const fn set_hcreset(&mut self, val: bool)
Host Controller Reset: This control bit is used by the software to reset the host controller.
Sourcepub const fn fls(&self) -> u8
pub const fn fls(&self) -> u8
Frame List Size: This field specifies the size of the frame list.
Sourcepub const fn set_fls(&mut self, val: u8)
pub const fn set_fls(&mut self, val: u8)
Frame List Size: This field specifies the size of the frame list.
Sourcepub const fn lhcr(&self) -> bool
pub const fn lhcr(&self) -> bool
Light Host Controller Reset: This bit allows the driver software to reset the host controller without affecting the state of the ports.
Sourcepub const fn set_lhcr(&mut self, val: bool)
pub const fn set_lhcr(&mut self, val: bool)
Light Host Controller Reset: This bit allows the driver software to reset the host controller without affecting the state of the ports.
Sourcepub const fn set_atl_en(&mut self, val: bool)
pub const fn set_atl_en(&mut self, val: bool)
ATL List enabled.
Sourcepub const fn set_iso_en(&mut self, val: bool)
pub const fn set_iso_en(&mut self, val: bool)
ISO List enabled.
Sourcepub const fn set_int_en(&mut self, val: bool)
pub const fn set_int_en(&mut self, val: bool)
INT List enabled.