#[repr(transparent)]pub struct Atlptd(pub u32);Expand description
Memory base address where ATL PTD0 is stored
Tuple Fields
0: u32Implementations
Sourceimpl Atlptd
impl Atlptd
Sourcepub const fn atl_cur(&self) -> u8
pub const fn atl_cur(&self) -> u8
This indicates the current PTD that is used by the hardware when it is processing the ATL list.
Sourcepub const fn set_atl_cur(&mut self, val: u8)
pub const fn set_atl_cur(&mut self, val: u8)
This indicates the current PTD that is used by the hardware when it is processing the ATL list.
Sourcepub const fn atl_base(&self) -> u32
pub const fn atl_base(&self) -> u32
Base address to be used by the hardware to find the start of the ATL list.
Sourcepub const fn set_atl_base(&mut self, val: u32)
pub const fn set_atl_base(&mut self, val: u32)
Base address to be used by the hardware to find the start of the ATL list.